@@ -87,8 +87,6 @@ print_cant_auth_errbox (void)
 /**
  * gdm_verify_user:
  * @username: Name of user or NULL if we should ask
- * @display: Name of display to register with the authentication system
- * @local: boolean if local
  * @allow_retry: boolean.  Not used by verify-crypt.  If this code
  *               allowed the user to retry, this boolean would specify
  *               whether to enable this feature.  We only want this
@@ -104,8 +102,6 @@ print_cant_auth_errbox (void)
 gchar *
 gdm_verify_user (GdmDisplay *d,
 		 const char *username,
-		 const gchar *display,
-		 gboolean local,
 		 gboolean allow_retry)
 {
 	gchar *login, *passwd, *ppasswd;
@@ -120,7 +116,7 @@ gdm_verify_user (GdmDisplay *d,
 	gint reEnter, ret;
 #endif
 
-	if (local && d->timed_login_ok)
+	if (d->attached && d->timed_login_ok)
 		gdm_slave_greeter_ctl_no_ret (GDM_STARTTIMER, "");
 
 	if (username == NULL) {
@@ -138,7 +134,7 @@ gdm_verify_user (GdmDisplay *d,
 				selected_user = NULL;
 			} else {
 				/* some other interruption */
-				if (local)
+				if (d->attached)
 					gdm_slave_greeter_ctl_no_ret (GDM_STOPTIMER, "");
 				g_free (login);
 				return NULL;
@@ -189,7 +185,7 @@ gdm_verify_user (GdmDisplay *d,
 		if (passwd == NULL)
 			passwd = g_strdup ("");
 		if (gdm_slave_greeter_check_interruption ()) {
-			if (local)
+			if (d->attached)
 				gdm_slave_greeter_ctl_no_ret (GDM_STOPTIMER, "");
 			g_free (login);
 			g_free (passwd);
@@ -198,12 +194,12 @@ gdm_verify_user (GdmDisplay *d,
 		}
 	}
 
-	if (local)
+	if (d->attached)
 		gdm_slave_greeter_ctl_no_ret (GDM_STOPTIMER, "");
 
 	if (pwent == NULL) {
 		gdm_sleep_no_signal (gdm_daemon_config_get_value_int (GDM_KEY_RETRY_DELAY));
-		g_warning (_("Couldn't authenticate user \"%s\""), login);
+		g_warning ("Couldn't authenticate user");
 
 		print_cant_auth_errbox ();
 
@@ -217,7 +213,7 @@ gdm_verify_user (GdmDisplay *d,
 	if (ppasswd == NULL || (ppasswd[0] != '\0' &&
 				strcmp (crypt (passwd, ppasswd), ppasswd) != 0)) {
 		gdm_sleep_no_signal (gdm_daemon_config_get_value_int (GDM_KEY_RETRY_DELAY));
-		g_warning (_("Couldn't authenticate user \"%s\""), login);
+		g_warning ("Couldn't authenticate user");
 
 		print_cant_auth_errbox ();
 
@@ -227,10 +223,11 @@ gdm_verify_user (GdmDisplay *d,
 		return NULL;
 	}
 
-	if ( ( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_ROOT)||
-	       ( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_REMOTE_ROOT) && ! local) ) &&
-	     pwent->pw_uid == 0) {
-		g_warning (_("Root login disallowed on display '%s'"), display);
+	if (( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_ROOT) ||
+	    ( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_REMOTE_ROOT) &&
+              ! d->attached)) && pwent->pw_uid == 0) {
+
+		g_warning ("Root login disallowed on display '%s'", d->name);
 		gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
 					      _("The system administrator "
 						"is not allowed to login "
@@ -248,7 +245,7 @@ gdm_verify_user (GdmDisplay *d,
 	/* Check with the 'loginrestrictions' function
 	   if the user has been disallowed */
 	if (loginrestrictions (login, 0, NULL, &message) != 0) {
-		g_warning (_("User %s not allowed to log in"), login);
+		g_warning ("User not allowed to log in");
 		gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
 					      _("\nThe system administrator "
 						"has disabled your "
@@ -269,10 +266,10 @@ gdm_verify_user (GdmDisplay *d,
 
 	/* check for the standard method of disallowing users */
 	if (pwent->pw_shell != NULL &&
-	    (strcmp (pwent->pw_shell, "/sbin/nologin") == 0 ||
+	    (strcmp (pwent->pw_shell, NOLOGIN) == 0 ||
 	     strcmp (pwent->pw_shell, "/bin/true") == 0 ||
 	     strcmp (pwent->pw_shell, "/bin/false") == 0)) {
-		g_warning (_("User %s not allowed to log in"), login);
+		g_warning ("User not allowed to log in");
 		gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
 					      _("\nThe system administrator "
 						"has disabled your "
@@ -297,7 +294,7 @@ gdm_verify_user (GdmDisplay *d,
 	}
 
 	if ( ! gdm_setup_gids (login, pwent->pw_gid)) {
-		g_warning (_("Cannot set user group for %s"), login);
+		g_warning ("Cannot set user group");
 		gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
 					      _("\nCannot set your user group; "
 						"you will not be able to log in. "
@@ -310,7 +307,7 @@ gdm_verify_user (GdmDisplay *d,
 
 	switch (passwdexpired (login, &info_msg)) {
 	case 1 :
-		g_warning (_("Password of %s has expired"), login);
+		g_warning ("User password has expired");
 		gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
 					_("You are required to change your password.\n"
 					  "Please choose a new one."));
@@ -384,7 +381,7 @@ gdm_verify_user (GdmDisplay *d,
 		break;
 
 	case 2 :
-		g_warning (_("Password of %s has expired"), login);
+		g_warning ("User password has expired");
 		gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
 					_("Your password has expired.\n"
 					  "Only a system administrator can now change it"));
@@ -393,7 +390,7 @@ gdm_verify_user (GdmDisplay *d,
 		break;
 
 	case -1 :
-		g_warning (_("Internal error on passwdexpired"));
+		g_warning ("Internal error on passwdexpired");
 		gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
 					_("An internal error occurred. You will not be able to log in.\n"
 					  "Please try again later or contact your system administrator."));
@@ -414,7 +411,6 @@ gdm_verify_user (GdmDisplay *d,
 /**
  * gdm_verify_setup_user:
  * @login: The name of the user
- * @display: The name of the display
  *
  * This is used for auto loging in.  This just sets up the login
  * session for this user
@@ -423,7 +419,6 @@ gdm_verify_user (GdmDisplay *d,
 gboolean
 gdm_verify_setup_user (GdmDisplay *d,
                        const gchar *login,
-                       const gchar *display,
 		       char **new_login)
 {
 	struct passwd *pwent;
@@ -432,12 +427,12 @@ gdm_verify_setup_user (GdmDisplay *d,
 
 	pwent = getpwnam (login);
 	if (pwent == NULL) {
-		g_warning (_("Cannot get passwd structure for %s"), login);
+		g_warning ("Cannot get passwd structure for user");
 		return FALSE;
 	}
 
 	if ( ! gdm_setup_gids (login, pwent->pw_gid)) {
-		g_warning (_("Cannot set user group for %s"), login);
+		g_warning ("Cannot set user group");
 		gdm_errorgui_error_box (d,
 					GTK_MESSAGE_ERROR,
 					_("\nCannot set your user group; "
