@@ -681,7 +681,9 @@ pre_fetch_run (gpointer data)
 	g_spawn_async (".",
 		       pre_fetch_prog_argv,
 		       NULL,
-		       (GSpawnFlags) (G_SPAWN_SEARCH_PATH),
+		       (GSpawnFlags) (G_SPAWN_SEARCH_PATH | 
+                              G_SPAWN_STDOUT_TO_DEV_NULL |
+                              G_SPAWN_STDERR_TO_DEV_NULL),
 		       NULL,
 		       NULL,
 		       &pid,
@@ -702,7 +704,7 @@ pre_atspi_launch (void){
 	if (! a11y)
 		return FALSE;
 
-	command = g_strdup (LIBEXECDIR "/at-spi-registryd");
+	command = g_strdup (ATSPIDIR "/at-spi-registryd");
 
 	atspi_prog_argv = NULL;
 	g_shell_parse_argv (command, NULL, &atspi_prog_argv, NULL);
@@ -710,7 +712,9 @@ pre_atspi_launch (void){
 	g_spawn_async (".",
 		       atspi_prog_argv,
 		       NULL,
-		       (GSpawnFlags) (G_SPAWN_SEARCH_PATH),
+		       (GSpawnFlags) (G_SPAWN_SEARCH_PATH |
+                              G_SPAWN_STDOUT_TO_DEV_NULL |
+                              G_SPAWN_STDERR_TO_DEV_NULL),
 		       NULL,
 		       NULL,
 		       &pid,
