@@ -569,6 +569,8 @@ process_operation (guchar       op_code,
 	gdm_wm_save_wm_order ();
 
 	gdk_flush ();
+	printf ("%c\n", STX);
+	fflush (stdout);
 
 	_exit (EXIT_SUCCESS);
 
@@ -859,6 +861,7 @@ static void
 gdm_read_config (void)
 {
 	gint i;
+	gchar *key_string = NULL;
 
 	/* Read config data in bulk */
 	gdmcomm_comm_bulk_start ();
@@ -921,23 +924,25 @@ gdm_read_config (void)
 	gdm_config_get_bool   (GDM_KEY_BROWSER);
 
 	/* Keys for custom commands */
-	for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {
-		gchar * key_string = NULL;
+	for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
 		gdm_config_get_string (key_string);
-
+		g_free (key_string);
+		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
 		gdm_config_get_string (key_string);
+		g_free (key_string);
 		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_LR_LABEL_TEMPLATE, i);
 		gdm_config_get_string (key_string);
+		g_free (key_string);
 		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEXT_TEMPLATE, i);
 		gdm_config_get_string (key_string);
-        
+		g_free (key_string);
+		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TOOLTIP_TEMPLATE, i);
 		gdm_config_get_string (key_string);
-
 		g_free (key_string);
 	}     
 
@@ -953,7 +958,8 @@ greeter_reread_config (int sig, gpointer data)
 {
 	gint i;
 	gboolean custom_changed = FALSE;
-
+	gchar *key_string = NULL;
+	
 	/* Read config data in bulk */
 	gdmcomm_comm_bulk_start ();
 
@@ -1015,28 +1021,30 @@ greeter_reread_config (int sig, gpointer data)
 		_exit (DISPLAY_RESTARTGREETER);
 	}
 
-	for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {
-		gchar *key_string = NULL;
+	for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
+		g_free (key_string);
 		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
+		g_free (key_string);
 		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_LR_LABEL_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
+		g_free (key_string);
 		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEXT_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
+		g_free (key_string);
 		
 		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TOOLTIP_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
-
 		g_free (key_string);
 	}     	
 	
@@ -1123,15 +1131,17 @@ get_theme_file (const char *in, char **theme_dir)
   *theme_dir = dir;
 
   info = g_build_filename (dir, "GdmGreeterTheme.desktop", NULL);
-  if (g_access (info, F_OK) != 0) {
+  if (g_access (info, R_OK) != 0) {
+	  g_debug ("Could not open %s. The file either doesn't exist or is not readable", info);
 	  g_free (info);
 	  info = g_build_filename (dir, "GdmGreeterTheme.info", NULL);
   }
-  if (g_access (info, F_OK) != 0)
+  if (g_access (info, R_OK) != 0)
     {
       char *base = g_path_get_basename (in);
       /* just guess the name, we have no info about the theme at
        * this point */
+      g_debug ("Could not open %s. The file either doesn't exist or is not readable", info);
       g_free (info);
       file = g_strdup_printf ("%s/%s.xml", dir, base);
       g_free (base);
@@ -1232,6 +1242,7 @@ main (int argc, char *argv[])
   guint sid;
   int r;
   gint i;
+  gchar *key_string = NULL;
 
   if (g_getenv ("DOING_GDM_DEVELOPMENT") != NULL)
     DOING_GDM_DEVELOPMENT = TRUE;
@@ -1264,6 +1275,8 @@ main (int argc, char *argv[])
   gdm_common_log_init ();
   gdm_common_log_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
 
+  gdm_common_setup_builtin_icons ();
+
   /* Read all configuration at once, so the values get cached */
   gdm_read_config ();
 
@@ -1372,7 +1385,6 @@ main (int argc, char *argv[])
 
   GdmCustomCmdsFound = g_new0 (gboolean, GDM_CUSTOM_COMMAND_MAX);
   for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {
-	  gchar * key_string = NULL;
 	  /*  For each possible custom command */      
 	  key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
 	  GdmCustomCmdsFound[i] = gdm_working_command_exists (gdm_config_get_string (key_string));
